@@ -1,9 +1,9 @@
 StatNText <- ggplot2::ggproto("StatNText", ggplot2::Stat,
 
-  required_aes = c("x", "y"), 
+  required_aes = c("x", "y"),
 
   setup_params = function(data, params) {
-    if(!is.null(params$y.pos)) 
+    if(!is.null(params$y.pos))
       return(params)
 
     range.y <- range(data$y, na.rm = TRUE)
@@ -11,13 +11,11 @@ StatNText <- ggplot2::ggproto("StatNText", ggplot2::Stat,
     params$y.pos <- pos
     params
   },
-  
-  compute_panel = function(data, scales, y.pos, y.expand.factor) {
-    n.tibble <- dplyr::summarise(dplyr::group_by(data, x), N = sum(!is.na(y)))
 
-    n.vec <- unlist(n.tibble[, "N"])
+  compute_panel = function(data, scales, y.pos, y.expand.factor) {
+    n.vec <- as.vector(by(data$y, data$x, function(x) length(na.omit(x))))
     lab <- paste0("n=", n.vec)
 
-    data.frame(x = unlist(n.tibble[, "x"]), y = y.pos, label = lab)
+    data.frame(x = as.vector(by(data$x, data$x, function(x)x[1])), y = y.pos, label = lab)
   }
 )
